package com.reactnative.socialcommerce.contentmanagement.component

import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.uimanager.ViewGroupManager
import android.widget.FrameLayout
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.bridge.ReadableArray
import android.view.ViewGroup
import android.view.Choreographer
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import com.facebook.react.bridge.Arguments
import com.facebook.react.common.MapBuilder
import com.facebook.react.modules.core.DeviceEventManagerModule
import com.loopnow.library.content.management.fragment.ListIndexFragment
import com.loopnow.library.content.management.fragment.callback.ITitleDelegate

class VideoListView(var reactContext: ReactApplicationContext) :
    ViewGroupManager<FrameLayout>() {
    val COMMAND_CREATE = 1
    override fun getName(): String {
        return REACT_CLASS
    }

    /**
     * Return a FrameLayout which will later hold the Fragment
     */
    public override fun createViewInstance(reactContext: ThemedReactContext): FrameLayout {
        return FrameLayout(reactContext)
    }

    /**
     * Map the "create" command to an integer
     */
    override fun getCommandsMap(): Map<String, Int>? {
        return MapBuilder.of("create", COMMAND_CREATE)
    }

    /**
     * Handle "create" command (called from JS) and call createFragment method
     */
    override fun receiveCommand(
        root: FrameLayout,
        commandId: String,
        args: ReadableArray?
    ) {
        super.receiveCommand(root, commandId, args)
        val reactNativeViewId = args!!.getInt(0)
        val commandIdInt = commandId.toInt()
        when (commandIdInt) {
            COMMAND_CREATE -> createFragment(root, reactNativeViewId)
            else -> {
            }
        }
    }

    /**
     * Replace your React Native view with a custom fragment
     */
    private fun createFragment(root: FrameLayout, reactNativeViewId: Int) {
        val parentView = root.findViewById<View>(reactNativeViewId) as ViewGroup
        val myFragment = ListIndexFragment.newInstance()
        myFragment.titleDelegate = object : ITitleDelegate {
            override fun setTitle(title: CharSequence, fragment: Fragment) {
                changeTitle(title)
            }
        }
        setupLayout(parentView)
        val activity = reactContext.currentActivity as FragmentActivity?
        activity!!.supportFragmentManager
            .beginTransaction()
            .replace(reactNativeViewId, myFragment, reactNativeViewId.toString())
            .commit()
    }

    private fun changeTitle(title: CharSequence) {
        val params = Arguments.createMap().apply {
            putString("title", title.toString())
        }
        this@VideoListView.reactContext.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter::class.java)
            .emit("changeNavigationTitle", params)
    }

    private fun setupLayout(view: View) {
        Choreographer.getInstance().postFrameCallback(object : Choreographer.FrameCallback {
            override fun doFrame(frameTimeNanos: Long) {
                view.measure(
                    View.MeasureSpec.makeMeasureSpec(view.width, View.MeasureSpec.EXACTLY),
                    View.MeasureSpec.makeMeasureSpec(view.height, View.MeasureSpec.EXACTLY)
                )
                view.layout(0, 0, view.width, view.height)
                view.viewTreeObserver.dispatchOnGlobalLayout()
                Choreographer.getInstance().postFrameCallback(this)
            }
        })
    }

    companion object {
        const val REACT_CLASS = "VideoListView"
    }
}
