//
//  AuthenticationModule+ModelConvert.swift
//  SocialCommerceExample
//
//  Created by Jeff Zheng on 2022/5/28.
//

import Foundation
import UserCenter
import Authentication
import RestClient

extension AuthenticationModule {
    func convertUserInfo(user: HostUserResponseData) -> [String: Any]? {
        let fwUser = FWUserInfo(uid: user.encodedID, username: user.username, name: user.name)

        return JsonHelper.fromObject(object: fwUser)
    }

    func convertCredential(refreshCredential: RefreshableCredential) -> [String: Any]? {
        let timeInterval = refreshCredential.accessTokenExpirationDate.timeIntervalSince1970
        let credential = Credential(accessToken: refreshCredential.accessToken, expirationDate: timeInterval)

        return JsonHelper.fromObject(object: credential)
    }

    func convertCredential(refreshCredential: RefreshableCredential) -> LoginResult {
        let timeInterval = refreshCredential.accessTokenExpirationDate.timeIntervalSince1970
        let credential = Credential(accessToken: refreshCredential.accessToken, expirationDate: timeInterval)

        let loginResult = LoginResult(canceled: false, credential: credential)

        return loginResult
    }

    func convertError(error: FireworkNetworkError) -> FWError {
        let fwError = FWError(name: error.failureReason ?? "", reason: error.errorDescription)

        return fwError
    }

    func convertError(error: AuthenticationError) -> FWError {
        let fwError = FWError(name: error.description, reason: error.description)

        return fwError
    }
}

extension AuthenticationModule {
    func convertBusinesses(responseData: BusinessesResponseData) -> [String: Any]? {
        var wrapper = SCBusinessResponseData()
        guard let businesses = responseData.businesses else {
            return JsonHelper.fromObject(object: wrapper)
        }

        let businessList = businesses.map { element in
            return SCBusiness(businessId: element.id, businessName: element.name)
        }

        wrapper.businessList = businessList

        return JsonHelper.fromObject(object: wrapper)
    }

    func convertChannels(responseData: ChannelsResponseData) -> [String: Any]? {
        var wrapper = SCChannelResponseData()
        guard let channels = responseData.channels else {
            return JsonHelper.fromObject(object: wrapper)
        }

        let channelList = channels.map { element in
            return SCChannel(channelId: element.id, channelName: element.name)
        }

        wrapper.channelList = channelList

        return JsonHelper.fromObject(object: wrapper)
    }
}
