//
//  AuthenticationModule+Brand.swift
//  SocialCommerceExample
//
//  Created by Jeff Zheng on 2022/5/28.
//

import Foundation
import UserCenter
import React

extension AuthenticationModule {
  @objc(getBusinessListPage:pageSize:resolver:rejecter:)
  func getBusinessList(page: UInt,
                       pageSize: UInt,
                       resolver: @escaping RCTPromiseResolveBlock,
                       rejecter: @escaping RCTPromiseRejectBlock) {
        UserCenterManager.shared.getBusinessList(next: nil) { result in
            switch result {
            case .success(let data):
                let jsonObject = self.convertBusinesses(responseData: data)
                resolver(jsonObject)
            case .failure(let error):
                let error = self.convertError(error: error)
                rejecter(error.name, error.reason, error)
            }
        }
    }

    @objc(getChannelListBusinessId:page:pageSize:resolver:rejecter:)
    func getChannelList(businessId: String,
                        page: UInt,
                        pageSize: UInt,
                        resolver: @escaping RCTPromiseResolveBlock,
                        rejecter: @escaping RCTPromiseRejectBlock) {
        UserCenterManager.shared.getChannelList(businessId: businessId, next: nil) { result in
            switch result {
            case .success(let data):
                let jsonObject = self.convertChannels(responseData: data)
                resolver(jsonObject)
            case .failure(let error):
                let error = self.convertError(error: error)
                rejecter(error.name, error.reason, error)
            }
        }
    }

    @objc(changeCurrentChannelBusinessId:channelId:resolver:rejecter:)
    func changeCurrentChannel(businessId: String,
                              channelId: String,
                              resolver: @escaping RCTPromiseResolveBlock,
                              rejecter: @escaping RCTPromiseRejectBlock) {
        let success = UserCenterManager.shared.changeCurrentChannel(businessId: businessId,
                                                                    channelId: channelId)
        resolver(success)
    }

    @objc(getCurrentOrgInfoRsolver:rejecter:)
    func getCurrentOrgInfo(resolver: @escaping RCTPromiseResolveBlock,
                           rejecter: @escaping RCTPromiseRejectBlock) {
        let rawUserInfo = UserCenterManager.shared.getUserInfo()
        let rawBusiness = UserCenterManager.shared.getCurrentBusiness()
        let rawChannel = UserCenterManager.shared.getCurrentChannel()

        var orgInfo = CurrentOrganizationInfo()
        if let rawUserInfo = rawUserInfo {
            orgInfo.userInfo = FWUserInfo(uid: rawUserInfo.encodedID,
                                        username: rawUserInfo.username,
                                        name: rawUserInfo.name)
        }
        if let rawBusiness = rawBusiness {
            orgInfo.business = SCBusiness(businessId: rawBusiness.id, businessName: rawBusiness.name)
        }
        if let rawChannel = rawChannel {
            orgInfo.channel = SCChannel(channelId: rawChannel.id, channelName: rawChannel.name)
        }

        let jsonObject = JsonHelper.fromObject(object: orgInfo)
        resolver(jsonObject)
    }
}
