//
//  JsonHelper.swift
//  react-native-social-commerce
//
//  Created by Jeff Zheng on 2022/4/14.
//

import Foundation

class JsonHelper {
    static func fromDictionary<T>(_ config: [String: AnyObject]?, type: T.Type) -> T? where T: Decodable {
        guard let config = config else {
            return nil
        }

        let jsonData = try? JSONSerialization.data(withJSONObject: config, options: .prettyPrinted)
        guard let jsonData = jsonData else {
            return nil
        }

        var result: T?
        do {
            result = try JSONDecoder().decode(type, from: jsonData)
        } catch let error {
            print(error.localizedDescription)
        }

        return result
    }

    static func fromObject<T>(object: T?) -> [String: Any]? where T: Encodable {
        guard let object = object else {
            return nil
        }

        let data = try? JSONEncoder().encode(object)
        guard let data = data else {
            return nil
        }

      var result: [String: Any]?
        do {
            result = try JSONSerialization.jsonObject(with: data, options: .allowFragments) as? [String: Any]
        } catch let error {
            print(error.localizedDescription)
        }

        return result
    }
}
