"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _AuthenticationModule = _interopRequireDefault(require("./modules/AuthenticationModule"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class AuthenticationManager {
  static getInstance() {
    if (!AuthenticationManager.instance) {
      AuthenticationManager.instance = new AuthenticationManager();
    }

    return AuthenticationManager.instance;
  }
  /**
   * Host app can call this method to present a firework login screen, then can get an access token after the user authorizes it.
   */


  login() {
    return _AuthenticationModule.default.login();
  }
  /**
   * After login success, the host needs to call this method to prepare firework’s basic info so that it can use firework’s feature.
   */


  syncCurrentOrganization() {
    return _AuthenticationModule.default.syncCurrentOrganization();
  }
  /**
   * Host can call this method to get a token, if there is no token, the host needs to call the login method.
   */


  getMerchantToken() {
    return _AuthenticationModule.default.getMerchantToken();
  }

  getAccessToken() {
    return _AuthenticationModule.default.getAccessToken();
  }
  /**
   * Host can call this method to refresh the token when the merchant token expires.
   */


  refreshToken() {
    return _AuthenticationModule.default.refreshToken();
  }
  /**
   * Host needs to call this method to clear local token info when user tap logout
   */


  logout() {
    _AuthenticationModule.default.logout();
  }

  getBusinessList(page, pageSize) {
    return _AuthenticationModule.default.getBusinessList(page !== null && page !== void 0 ? page : 0, pageSize !== null && pageSize !== void 0 ? pageSize : 30);
  }

  getChannelList(businessId, page, pageSize) {
    return _AuthenticationModule.default.getChannelList(businessId, page !== null && page !== void 0 ? page : 0, pageSize !== null && pageSize !== void 0 ? pageSize : 30);
  }

  getStoreList(businessId, page, pageSize) {
    return _AuthenticationModule.default.getStoreList(businessId, page !== null && page !== void 0 ? page : 0, pageSize !== null && pageSize !== void 0 ? pageSize : 30);
  }

  changeCurrentChannel(businessId, channelId) {
    return _AuthenticationModule.default.changeCurrentChannel(businessId, channelId);
  }

  changeCurrentStore(businessId, storeId) {
    return _AuthenticationModule.default.changeCurrentStore(businessId, storeId);
  }

  getCurrentOrgInfo() {
    return _AuthenticationModule.default.getCurrentOrgInfo();
  }

}

_defineProperty(AuthenticationManager, "instance", void 0);

var _default = AuthenticationManager;
exports.default = _default;
//# sourceMappingURL=AuthenticationManager.js.map