import type BusinessResponseData from './models/Business';
import type ChannelResponseData from './models/Channel';
import type Credential from './models/Credential';
import type LoginResult from './models/LoginResult';
import type StoreResponseData from './models/Store';
import type CurrentOrganizationInfo from './models/CurrentOrganizationInfo';
declare class AuthenticationManager {
    private static instance?;
    static getInstance(): AuthenticationManager;
    /**
     * Host app can call this method to present a firework login screen, then can get an access token after the user authorizes it.
     */
    login(): Promise<LoginResult>;
    /**
     * After login success, the host needs to call this method to prepare firework’s basic info so that it can use firework’s feature.
     */
    syncCurrentOrganization(): Promise<boolean>;
    /**
     * Host can call this method to get a token, if there is no token, the host needs to call the login method.
     */
    getMerchantToken(): Promise<Object>;
    getAccessToken(): Promise<Credential>;
    /**
     * Host can call this method to refresh the token when the merchant token expires.
     */
    refreshToken(): Promise<Credential>;
    /**
     * Host needs to call this method to clear local token info when user tap logout
     */
    logout(): void;
    getBusinessList(page?: number, pageSize?: number): Promise<BusinessResponseData>;
    getChannelList(businessId: string, page?: number, pageSize?: number): Promise<ChannelResponseData>;
    getStoreList(businessId: string, page?: number, pageSize?: number): Promise<StoreResponseData>;
    changeCurrentChannel(businessId: string, channelId: string): Promise<boolean>;
    changeCurrentStore(businessId: string, storeId: string): Promise<boolean>;
    getCurrentOrgInfo(): Promise<CurrentOrganizationInfo>;
}
export default AuthenticationManager;
