// import type { NativeStackScreenProps } from '@react-navigation/native-stack';
import React from 'react';
import {
  findNodeHandle,
  NativeEventEmitter,
  NativeModules,
  requireNativeComponent,
  StyleSheet,
  UIManager,
  Platform,
  View,
  EmitterSubscription,
} from 'react-native';

// type Props = NativeStackScreenProps<any, 'Video'>;

type ChangeTitleEvent = {
  title: string;
};

const LINKING_ERROR =
  `The package 'AuthenticationModule' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo managed workflow\n';

const VideoListView =
  UIManager.getViewManagerConfig('VideoListView') != null
    ? requireNativeComponent<any>('VideoListView')
    : () => {
        throw new Error(LINKING_ERROR);
      };

const createFragment = (viewId: number | null) => {
  try {
    UIManager.dispatchViewManagerCommand(
      viewId,
      UIManager.getViewManagerConfig(
        'VideoListView',
      ).Commands.create.toString(),
      [viewId],
    );
  } catch (ignored) {}
};

const eventEmitter = new NativeEventEmitter(NativeModules.SocialCommerceModule);

// const VideoScreen = ({ navigation }: any) => {
//   const ref = useRef(null);

//   useEffect(() => {
//     if (Platform.OS === 'android') {
//       const viewId = findNodeHandle(ref.current);
//       createFragment(viewId);
//     }
//   }, []);

//   useEffect(() => {
//     const sub = eventEmitter.addListener(
//       'changeNavigationTitle',
//       (event: ChangeTitleEvent) => {
//         navigation.setOptions({ title: event.title });
//       },
//     );
//     return () => {
//       sub.remove();
//     };
//   }, [navigation]);

//   return (
//     <View style={styles.container}>
//       <VideoListView style={styles.videoView} ref={ref} />
//     </View>
//   );
// };
export interface IVideoProps {
  navigation: any;
}

class VideoScreen extends React.Component<IVideoProps> {
  ref = React.createRef<any>();

  subscriptions: EmitterSubscription | undefined;

  componentDidMount() {
    if (Platform.OS === 'android') {
      const viewId = findNodeHandle(this.ref.current);
      createFragment(viewId);
    }

    this.subscriptions = eventEmitter.addListener(
      'changeNavigationTitle',
      (event: ChangeTitleEvent) => {
        this.props.navigation.setOptions({ title: event.title });
      },
    );
  }

  componentWillUnmount() {
    if (this.subscriptions) {
      this.subscriptions.remove();
    }
  }

  render() {
    return (
      <View style={styles.container}>
        <VideoListView style={styles.videoView} ref={this.ref} />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#e4f0ee',
  },
  videoView: {
    width: '100%',
    height: '100%',
  },
});

export default VideoScreen;
