import { NativeModules, Platform } from 'react-native';
import type BusinessResponseData from 'src/models/Business';
import type ChannelResponseData from 'src/models/Channel';
import type Credential from 'src/models/Credential';
import type LoginResult from 'src/models/LoginResult';
import type StoreResponseData from 'src/models/Store';
import type CurrentOrganizationInfo from 'src/models/CurrentOrganizationInfo';

const LINKING_ERROR =
  `The package 'AuthenticationModule' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo managed workflow\n';

const AuthenticationModule = NativeModules.AuthenticationModule
  ? NativeModules.AuthenticationModule
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      },
    );

interface IAuthenticationModule {
  login(): Promise<LoginResult>;
  syncCurrentOrganization(): Promise<boolean>;
  getAccessToken(): Promise<Credential>;
  getMerchantToken(): Promise<object>;
  refreshToken(): Promise<Credential>;
  logout(): void;

  getBusinessList(
    page?: number,
    pageSize?: number,
  ): Promise<BusinessResponseData>;
  getChannelList(
    business_id: string,
    page?: number,
    pageSize?: number,
  ): Promise<ChannelResponseData>;
  getStoreList(
    business_id: string,
    page?: number,
    pageSize?: number,
  ): Promise<StoreResponseData>;

  changeCurrentChannel(
    business_id: string,
    channel_id: string,
  ): Promise<boolean>;
  changeCurrentStore(business_id: string, store_id: string): Promise<boolean>;
  getCurrentOrgInfo(): Promise<CurrentOrganizationInfo>;
}

export default AuthenticationModule as IAuthenticationModule;
